# Contributors

You will find here the list of people who contributed to the ***Hrflow.ai Connector*** project.

* Clement Négre <clement.negre@hrflow.ai>
* 🐧 Corentin Duchêne <corentin.duchene@hrflow.ai> / Nigiva <contact@nigiva.com>
* Limam Vadhel <limam.vadhel@hrflow.ai>

